# -*- coding: utf-8 -*-
"""Persistence.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Img import Img, persistent
from micado.recipes.McdDetPersistence import McdDetPersistence
from micado.main.Raw import Raw
from micado.dataitems.PersistenceExtension import PersistenceExtension


class Persistence(Img):
    """Persistence image."""

    mjdobs = persistent(
        "Modified Julian Day of the start of the exposure. The MJD is related to the "
        "Julian Day (JD) via the formula: MJD = JD-2400000.5 The comment includes a "
        "civil representation of the date and time. 8 decimals are required for a "
        "precision of one millisecond, 5 decimals for a precision of one second. [MJD-"
        "OBS][]",
        float,
        0.0,
    )

    recipe = persistent("The recipe [][None]", McdDetPersistence, None)

    raw = persistent(
        "The raw to create this persistence correction for [][None]", Raw, None
    )

    raws = persistent("A list of raw sky data [][None]", Raw, [])

    extensions = persistent("PersistenceExtensions [][None]", PersistenceExtension, [])
