# -*- coding: utf-8 -*-
"""Regrid.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Img import Img, persistent
from micado.recipes.McdImgRegrid import McdImgRegrid
from micado.dataitems.Calibrated import Calibrated
from micado.dataitems.RegridExtension import RegridExtension
from micado.dataitems.RegridQC import RegridQC


class Regrid(Img):
    """Regridded Astrometric Imaging image."""

    det_dit = persistent(
        "Detector integration time (average when NDIT > 1) [DET DIT][s]", float, 1.0
    )

    filtname = persistent("Filter name [INS FILT NAME][None]", str, "open")

    mjdobs = persistent(
        "Modified Julian Day of the start of the exposure. The MJD is related to the "
        "Julian Day (JD) via the formula: MJD = JD-2400000.5 The comment includes a "
        "civil representation of the date and time. 8 decimals are required for a "
        "precision of one millisecond, 5 decimals for a precision of one second. [MJD-"
        "OBS][]",
        float,
        0.0,
    )

    tpl__start = persistent("Start time of template [TPL START][None]", float, 0.0)

    ra = persistent("Right Ascension [OBS RA][deg]", float, 0.0)

    dec = persistent("Declination [OBS DEC][deg]", float, 0.0)

    recipe = persistent("The recipe [][None]", McdImgRegrid, None)

    calibrated = persistent("Fully calibrated image [][None]", Calibrated, None)

    extensions = persistent("CalibratedExtensions [][None]", RegridExtension, [])

    qc = persistent("Quality Control parameters [][None]", RegridQC, None)
