# -*- coding: utf-8 -*-
"""Staroffset.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Tab import Tab, persistent
from micado.dataitems.DetrendFinalHCIOffset import DetrendFinalHCIOffset
from micado.dataitems.PhotomBase import PhotomBase
from micado.recipes.McdImgStarPhotom import McdImgStarPhotom
from micado.requirements.DPScorostarzptandcentroid import DPScorostarzptandcentroid
from micado.dataitems.StaroffsetQC import StaroffsetQC


class Staroffset(Tab):
    """Staroffset.

    Measurement of the peak flux of the stellar PSF normalized in ADU/s
    without ND. Position of the star in pixel units.
    """

    detrend = persistent(
        "Observation of detrended bright star exposure through calibration filter, "
        "shifted star outside the coronagraph mask [][None]",
        DetrendFinalHCIOffset,
        None,
    )

    zpt_calib = persistent("Zeropoint of calibration filter [][None]", PhotomBase, None)

    zpt_science = persistent("Zeropoint of science filter [][None]", PhotomBase, None)

    recipe = persistent("The recipe [][None]", McdImgStarPhotom, None)

    requirement = persistent("None [][None]", DPScorostarzptandcentroid, None)

    qc = persistent("Quality Control parameters [][None]", StaroffsetQC, None)
