# -*- coding: utf-8 -*-
"""Atmosphere.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.HardwareThing import HardwareThing, persistent
from micado.hardware.SkycalcTERCurve import SkycalcTERCurve, default_skycalctercurve


class Atmosphere(HardwareThing):
    """The Atmosphere."""

    location = persistent("Location [ATM LOCATION][None]", str, "Armazones")

    altitude = persistent("Height of telescope [ATM ALTITUDE][m]", float, 3060.0)

    longitude = persistent(
        "Longitude of telescope [ATM LONGITUD][degree]", float, -70.1918
    )

    latitude = persistent(
        "Latitude of telescope [ATM LATITUDE][degree]", float, -24.5899
    )

    temperature = persistent("Temperature of telescope [ATM TEMPERAT][C]", float, 7.0)

    humidity = persistent("Humidity of atmosphere [ATM HUMIDITY][TODO]", float, 0.1)

    pressure = persistent("Pressure of atmosphere [ATM PRESSURE][TODO]", float, 0.755)

    pwv = persistent("PWV [ATM PWV][TODO]", float, 2.5)

    spectrum__filename = persistent(
        "File [ATM SPE FILENAME][None]", str, "TER_armazones_default_FULL_IMG.dat"
    )

    background__filter_name = persistent(
        "Background filter [ATM BKG FILT][None]", str, "Ks"
    )

    background__value = persistent(
        "Background value [ATM BKG VALUE][None]", float, 13.6
    )

    background__unit = persistent("Background unit [ATM BKG UNIT][None]", str, "mag")

    skycalc_atmosphere = persistent(
        "atmospheric spectra pulled from the skycalc server [][None]",
        SkycalcTERCurve,
        default_skycalctercurve,
    )


default_atmosphere = Atmosphere(
    location="Armazones",
    altitude=3060.0,
    longitude=-70.1918,
    latitude=-24.5899,
    temperature=7.0,
    humidity=0.1,
    pressure=0.755,
    pwv=2.5,
    spectrum__filename="TER_armazones_default_FULL_IMG.dat",
    background__filter_name="Ks",
    background__value=13.6,
    background__unit="mag",
    skycalc_atmosphere=default_skycalctercurve,
)
