# -*- coding: utf-8 -*-
"""Detector.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.Hardware import Hardware, persistent


class Detector(Hardware):
    """A single Detector."""

    id = persistent("Identifier of detector [DET ID][None]", str, "")

    angle = persistent("Angle of detector [DET ANGLE][degree]", float, 0.0)

    gain = persistent("Gain of the detector [GAIN][e/adu]", float, 1.0)

    pixel_size = persistent("Pixel size [DET PIXELSIZ][mm]", float, 0.015)

    x_cen = persistent("X center [DET X_CEN][mm]", float, 0.0)

    y_cen = persistent("Y center [DET Y_CEN][mm]", float, 0.0)

    x_size = persistent("x_size [DET X_SIZE][pix]", int, 4096)

    y_size = persistent("y_size [DET Y_SIZE][pix]", int, 4096)


default_detector = Detector(
    id="",
    angle=0.0,
    gain=1.0,
    pixel_size=0.015,
    x_cen=0.0,
    y_cen=0.0,
    x_size=4096,
    y_size=4096,
)
