# -*- coding: utf-8 -*-
"""FilterWheel.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.Effect import Effect, persistent


class FilterWheel(Effect):
    """Filter wheel."""

    name = persistent("Filter name [INS FILT NAME][None]", str, "open")

    minimum_throughput = persistent(
        "Make sure the the Filter effect is passing minimum_throughput larger than the "
        "wing transmission. I.e. if the TC has 0.0001 wings, set minimum_throughput : "
        "0.00011 [INS FILT MINIMUM_][None]",
        float,
        0.000101,
    )

    outer = persistent("Outer diameter of the filter. [INS FILT OUTER][m]", float, 0.2)


default_filterwheel = FilterWheel(
    name="open",
    minimum_throughput=0.000101,
    outer=0.2,
)
