# -*- coding: utf-8 -*-
"""Instrument.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.HardwareThing import HardwareThing, persistent
from micado.hardware.FilterWheel import FilterWheel, default_filterwheel
from micado.hardware.PupilWheel import PupilWheel, default_pupilwheel
from micado.hardware.SurfaceList import SurfaceList, default_surfacelist
from micado.hardware.NonCommonPathAberration import (
    NonCommonPathAberration,
    default_noncommonpathaberration,
)


class Instrument(HardwareThing):
    """The instrument."""

    name = persistent("Name of instrument [INS NAME][None]", str, "")

    temperature = persistent(
        "Temperature of the instrument. [INS TEMPERAT][C]", float, -190.0
    )

    ocs__pxscale = persistent("Pixel scale [OCS PXSCALE][arcsec/pix]", float, 0.004)

    plate_scale = persistent(
        "Plate scale [INS PLATE_SC][arcsec/mm]", float, 0.26666666666
    )

    drot = persistent("Derotator angle [INS DROT][degree]", float, 0.0)

    filter_wheel_1 = persistent(
        "The first filter wheel [][None]", FilterWheel, default_filterwheel
    )

    filter_wheel_2 = persistent(
        "The second filter wheel [][None]", FilterWheel, default_filterwheel
    )

    pupil_wheel = persistent("The pupil wheel [][None]", PupilWheel, default_pupilwheel)

    static_surfaces = persistent(
        "Static Mirrors [][None]", SurfaceList, default_surfacelist
    )

    ncpas_psf = persistent(
        "Non Common Path Aberrations [][None]",
        NonCommonPathAberration,
        default_noncommonpathaberration,
    )


default_instrument = Instrument(
    name="",
    temperature=-190.0,
    ocs__pxscale=0.004,
    plate_scale=0.26666666666,
    drot=0.0,
    filter_wheel_1=default_filterwheel,
    filter_wheel_2=default_filterwheel,
    pupil_wheel=default_pupilwheel,
    static_surfaces=default_surfacelist,
    ncpas_psf=default_noncommonpathaberration,
)
