# -*- coding: utf-8 -*-
"""RelayOptics.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.HardwareThing import HardwareThing, persistent
from micado.hardware.FieldConstantPSF import FieldConstantPSF, default_fieldconstantpsf
from micado.hardware.SurfaceList import SurfaceList, default_surfacelist


class RelayOptics(HardwareThing):
    """The relay optics."""

    psf = persistent("The PSF [][None]", FieldConstantPSF, default_fieldconstantpsf)

    surface_list = persistent("Surfaces [][None]", SurfaceList, default_surfacelist)


default_relayoptics = RelayOptics(
    psf=default_fieldconstantpsf,
    surface_list=default_surfacelist,
)
