# -*- coding: utf-8 -*-
"""mcd_det_dark recipe."""

import numpy
from micado.dataitems.MasterDark import MasterDark
from micado.dataitems.MasterDarkExtension import MasterDarkExtension
from micado.dataitems.MasterDarkQC import MasterDarkQC
from micado.main.Imstat import Imstat


def make(self: MasterDark):
    """mcd_det_dark recipe."""

    # TODO: Actually model all the DRL functions / RecipeSteps.

    self.extensions = []
    oexts = [d.extensions for d in self.darks]
    for darks in zip(*oexts):
        images = [dark.image for dark in darks]
        nexte = MasterDarkExtension(
            NAXIS=darks[0].NAXIS,
            NAXIS1=darks[0].NAXIS1,
            NAXIS2=darks[0].NAXIS2,
            BITPIX=darks[0].BITPIX,
            EXTNAME=darks[0].EXTNAME,
        )
        nexte.image = numpy.median(images, axis=0)

        uncertainties = [numpy.sqrt(dark.image) for dark in darks]
        nexte.uncertainty = numpy.mean(uncertainties, axis=0) / len(uncertainties)

        nexte.quality = numpy.zeros(darks[0].image.shape)
        # TODO, actually propagate something from the previous steps.

        self.extensions.append(nexte)

    # Create a statistics object.
    myimstat = Imstat(baseframe=self)
    myimstat.make()

    # Set QC parameters.
    self.qc = MasterDarkQC(
        darkmean=myimstat.mean,
        darkmed=myimstat.median,
        darkrms=myimstat.std,
        npixsat=0,
        fpixsat=0,
    )
