# -*- coding: utf-8 -*-
"""Test whether we can create a table of DataItems."""

from micado.dataitems.Dark import Dark
from micado.dataitems.IllumCorr import IllumCorr
from micado.dataitems.MasterDark import MasterDark
from micado.main.Raw import Raw


def test_dark():
    """Test the dark row."""
    assert Dark.name_eso() == "I_DARK_RAW"
    assert Dark.type_eso() == "DPR"
    assert Dark.dpr_catg_c() == "CALIB"
    assert Dark.dpr_tech_c() == "IMAGE,SI"
    assert Dark.dpr_type_c() == "DARK"


def test_raw():
    """Test the raw row."""
    assert Raw.name_eso() == "RAW"
    assert Raw.type_eso() == "DPR"


def test_masterdark():
    """Test the masterdark row."""
    assert MasterDark.name_eso() == "I_MASTER_DARK_IMG"
    assert MasterDark.type_eso() == "PRO"
    assert MasterDark.description() == "MasterDark calibration image."
    assert MasterDark.description_oneline() == "MasterDark calibration image."


def test_illumcorr():
    """Test IllumCorr."""
    smultiline = """IllumCorr.

Table with the coefficients of the polynomial describing the large-scale
variation in the illumination by the flatfield lamp, and gain (e-/ADU),
which is a single number per detector.
"""
    assert IllumCorr.description() == smultiline

    soneline = (
        "Table with the coefficients of the polynomial describing the "
        "large-scale variation in the illumination by the flatfield "
        "lamp, and gain (e-/ADU), which is a single number per detector."
    )

    assert IllumCorr.description_oneline() == soneline
