"""Check whether the *.yaml and *Extra.py files correspond to a Python file."""
from pathlib import Path
from micado.main.commonwrapper import classcache
from micado.main.RecipeStepExtra import RecipeStepBase, RecipeStepExtra
from micado.main.aweimports import RecipeStep

# Importing RecipeStep frow aweimports will fill the classcache.

PATH_SRC = Path(__file__).resolve().parent.parent.parent
PATH_YAML = PATH_SRC / "text"


def main():
    """Compare yaml and Extra files with Python files.

    E.g. these three should go together:
    - src/micado/dataitems/Bkgfield.py
    - src/micado/dataitems/BkgfieldExtra.py
    - src/text/raw/bkgfield.yaml

    Note that the yaml files are in lowercase and  might have underscores:
    - src/micado/recipes/CombineExposures.py
    - src/text/recipestep/combine_exposures.yaml
    """

    # Collect Python files.
    paths_pys = list(PATH_SRC.rglob("*.py"))
    names_pys = [p.stem.lower() for p in paths_pys]

    # Collect Yaml files
    paths_yamls = list(PATH_YAML.rglob("*.yaml"))
    # names_yamls = [p.stem.replace("_", "") for p in paths_yamls]
    names_yamls = [p.stem for p in paths_yamls if p.stem != "emptyrecipe"]
    names_yamls_missing = [p for p in names_yamls if p not in names_pys]
    assert not names_yamls_missing, names_yamls_missing

    # Collect Extra.py files
    paths_extras = list(PATH_SRC.rglob("*Extra.py"))
    names_extras = [p.stem.lower() for p in paths_extras]
    names_extras_withoutextra = [p.replace("extra", "") for p in names_extras]
    names_extras_missing = [p for p in names_extras_withoutextra if p not in names_pys]
    assert not names_extras_missing, names_extras_missing

    # Collect Recipe steps without a yaml file
    recipesteps_all = [
        v.aclass
        for v in classcache.values()
        if issubclass(v.aclass, RecipeStepBase)
        and v.aclass not in [RecipeStepBase, RecipeStepExtra, RecipeStep]
        and not v.aclass.__name__.endswith("Base")
    ]
    recipesteps_no_yaml = [
        r.__name__
        for r in recipesteps_all
        if not (PATH_YAML / "recipestep" / f"{r.__name__.lower()}.yaml").exists()
    ]
    # TODO: Enable
    assert not recipesteps_no_yaml, recipesteps_no_yaml


if __name__ == "__main__":
    main()
