"""Convert a float to a FITS-compatible value."""
from astropy.io.fits import Card


def fitsfloat(value):
    """Convert a float to a FITS-compatible value.

    See https://github.com/astropy/astropy/issues/5449

    The values of float-type persistent properties should be indentical in
    - memory,
    - the database, and
    - FITS headers.

    astropy rounds floats in FITS headers to 16 characters, so consistency
    means that this needs to be done for all floats.
    """
    if not isinstance(value, float):
        return value
    return Card.fromstring(str(Card("k", value))).value
